package sun.security.provider.certpath;

import sun.security.x509.AuthorityKeyIdentifierExtension;
import sun.security.x509.SubjectKeyIdentifierExtension;
import java.io.IOException;
import sun.security.x509.KeyIdentifier;
import java.security.cert.CertificateException;
import sun.security.x509.X509CertImpl;
import java.security.cert.X509Certificate;
import sun.security.util.Debug;

public class Vertex
{
    private static final Debug debug;
    private X509Certificate cert;
    private int index;
    private Throwable throwable;
    
    Vertex(X509Certificate cert) {
        this.cert = cert;
        this.index = -1;
    }
    
    public X509Certificate getCertificate() {
        return this.cert;
    }
    
    public int getIndex() {
        return this.index;
    }
    
    void setIndex(int index) {
        this.index = index;
    }
    
    public Throwable getThrowable() {
        return this.throwable;
    }
    
    void setThrowable(Throwable throwable) {
        this.throwable = throwable;
    }
    
    @Override
    public String toString() {
        return this.certToString() + this.throwableToString() + this.indexToString();
    }
    
    public String certToString() {
        StringBuilder sb = new StringBuilder();
        X509CertImpl impl;
        try {
            impl = X509CertImpl.toImpl(this.cert);
        }
        catch (CertificateException ex) {
            if (Vertex.debug != null) {
                Vertex.debug.println("Vertex.certToString() unexpected exception");
                ex.printStackTrace();
            }
            return sb.toString();
        }
        sb.append("Issuer:     ").append(impl.getIssuerX500Principal()).append("\n");
        sb.append("Subject:    ").append(impl.getSubjectX500Principal()).append("\n");
        sb.append("SerialNum:  ").append(impl.getSerialNumber().toString(16)).append("\n");
        sb.append("Expires:    ").append(impl.getNotAfter().toString()).append("\n");
        boolean[] issuerUniqueID = impl.getIssuerUniqueID();
        if (issuerUniqueID != null) {
            sb.append("IssuerUID:  ");
            for (int length = issuerUniqueID.length, i = 0; i < length; ++i) {
                sb.append((int)issuerUniqueID[i]);
            }
            sb.append("\n");
        }
        boolean[] subjectUniqueID = impl.getSubjectUniqueID();
        if (subjectUniqueID != null) {
            sb.append("SubjectUID: ");
            for (int length2 = subjectUniqueID.length, j = 0; j < length2; ++j) {
                sb.append((int)subjectUniqueID[j]);
            }
            sb.append("\n");
        }
        try {
            SubjectKeyIdentifierExtension subjectKeyIdentifierExtension = impl.getSubjectKeyIdentifierExtension();
            if (subjectKeyIdentifierExtension != null) {
                sb.append("SubjKeyID:  ").append(subjectKeyIdentifierExtension.get("key_id").toString());
            }
            AuthorityKeyIdentifierExtension authorityKeyIdentifierExtension = impl.getAuthorityKeyIdentifierExtension();
            if (authorityKeyIdentifierExtension != null) {
                sb.append("AuthKeyID:  ").append(((KeyIdentifier)authorityKeyIdentifierExtension.get("key_id")).toString());
            }
        }
        catch (IOException ex2) {
            if (Vertex.debug != null) {
                Vertex.debug.println("Vertex.certToString() unexpected exception");
                ex2.printStackTrace();
            }
        }
        return sb.toString();
    }
    
    public String throwableToString() {
        StringBuilder sb = new StringBuilder("Exception:  ");
        if (this.throwable != null) {
            sb.append(this.throwable.toString());
        }
        else {
            sb.append("null");
        }
        sb.append("\n");
        return sb.toString();
    }
    
    public String moreToString() {
        StringBuilder sb = new StringBuilder("Last cert?  ");
        sb.append((this.index == -1) ? "Yes" : "No");
        sb.append("\n");
        return sb.toString();
    }
    
    public String indexToString() {
        return "Index:      " + this.index + "\n";
    }
    
    static {
        debug = Debug.getInstance("certpath");
    }
}
